==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
var CheckedChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckedChangedEventArgsDescriptionMetadata, _super);
    function CheckedChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckedChangedEventArgsDescriptionMetadata.b = function (a) {
        if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
            CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(CheckedChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("IsChecked", "Boolean");
    };
    CheckedChangedEventArgsDescriptionMetadata.d = function (a) {
        CheckedChangedEventArgsDescriptionMetadata.b(a);
        a.ad("CheckedChangedEventArgs", function () { return new CheckedChangedEventArgsDescription(); });
        a.ac("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.$t = markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
}(Base));
export { CheckedChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
var CheckedChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckedChangedEventArgsDescriptionMetadata, _super);
    function CheckedChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CheckedChangedEventArgsDescriptionMetadata.b = function (a) {
        if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
            CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(CheckedChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("IsChecked", "Boolean");
        a.item("PrimaryKeyRef", "(w:PrimaryKey,wf:PrimaryKey)DataRef:object");
    };
    CheckedChangedEventArgsDescriptionMetadata.d = function (a) {
        CheckedChangedEventArgsDescriptionMetadata.b(a);
        a.ae("CheckedChangedEventArgs", function () { return new CheckedChangedEventArgsDescription(); });
        a.ad("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
    };
    CheckedChangedEventArgsDescriptionMetadata.$t = markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
}(Base));
export { CheckedChangedEventArgsDescriptionMetadata };
